==> AuthNetAim-1.2.5.tar.gz: AuthNetAim/lang/en_US.php <==
<?php
#A
$lang['advanced'] = 'Advanced';
$lang['alternate_post_url'] = 'Alternate Transaction Submission URL';
$lang['alternate_test_url'] = 'Alternate Test Transaction Submission URL';


#B


#C
$lang['checkout_button_message'] = 'Checkout';
$lang['checkout_message'] = 'Checkout using Authorize.NET';

#D


#E
$lang['error_configuration'] = 'This module is not properly configured';
$lang['error_held_for_review'] = 'Payment has been held for review';
$lang['error_missing_data'] = 'Some information required for successfull transaction processing is not set';
$lang['error_payment_declined'] = 'Payment has been declined';
$lang['error_restoring_state'] = 'A problem occurred restoring gateway state information';
$lang['error_unknown'] = 'The payment gateway returned information we dont understand at this time';


#F
$lang['friendlyname'] = 'Authorize.net AIM';
$lang['form_template'] = 'Form Template';

#G


#H
$lang['help'] = <<<EOT
<h3>What does this do?</h3>
<p>This module provides the ability for your customers to pay for their purchases using their credit card directly on your site using the Authorize.Net secure gateway.</p>
<h3>Why should I use it?</h3>
<p>This gateway works without redirecting the user to a different website, and then redirecting them back.  It allows the ability to provide your customers with a single user experience.</p>
<h3>Special Requirements</h3>
<p>This module requires that your web application be configured to prompt the user for credit card information, The Orders module can be configured to do this.</p>
<p>Also this module will require a validated secure environment.   You will need to purchase a validated certificate from an approvded provider, install that certificate in your web host environment, and then configure CMS Made Simple to work properly in a secure environment.</p>
<h3>How do I use it?</h3>
<p>Quite simply, once all of the dependencies are installed, you simply install the module.  Then configure the module in the Authorize.NET AIM control panel in the CMS Made Simple admin console, using the transaction id, and the API Login that are provided to you by authorize.net. Then navigate to the preferences tab in the Orders module and select this module as your chosen payment gateway.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the cms development forge at <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000 all can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author(s) directly.</li>  
</ul>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&lt;calguy1000@cmsmadesimple.org&gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
EOT;


#I
$lang['info_alternate_urls'] = 'Some payment gateways have &quot;Authorize.NET&quot; emulators to allow using that payment gateway with alternate software.   Along with other details, they will provide alternate URLS for submitting the transactions.   You may specify those URLS here.   If these values are blank, then the system default URLS are used';
$lang['info_md5hash'] = 'The key used to encrypt certain information about the transaction, and to verify that transaction information came from a valid server.   You should configure the identical value in your authorize.net settings';
$lang['info_loginid'] = 'Please enter the Login ID provided to you by your authorize.net reseller';
$lang['info_testmode'] = 'With test mode enabled, no real transactions will be processed';
$lang['info_transactionkey'] = 'The transaction key value supplied to you by your authorize.net reseller';
$lang['info_usetesturl'] = 'Use the Authorize.net development environment instead of the real environment (requires having a developer account)';

#J


#K


#L


#M
$lang['moddescription'] = 'A payment gateway for the E-commerce system that uses the AIM protocol from Authorize.net';

#N


#O


#P
$lang['postinstall'] = 'Module successfully installed.  Please visit the module admin panel and ensure all preferences are set properly';
$lang['postuninstall'] = 'This module has been successfully uninstalled';
$lang['preferences'] = 'Preferences';
$lang['prompt_form_template'] = 'Edit the Form Template';
$lang['prompt_md5hash'] = 'MD5 Hash';
$lang['prompt_loginid'] = 'Authorize.Net API Login ID';
$lang['prompt_testmode'] = 'Enable Test Mode';
$lang['prompt_transactionkey'] = 'Transaction Key';
$lang['prompt_usetesturl'] = 'Use Developer account';

#Q


#R
$lang['really_uninstall'] = 'Are you sure you want to uninstall this module.  Continuing may have bad effects on an operational website';

#S
$lang['submit'] = 'Submit';


#T

#U


#V


#W


#X


#Y


#Z


?>

==> AuthNetAim-1.2.6.tar.gz: AuthNetAim/lang/en_US.php <==
<?php
#A
$lang['advanced'] = 'Advanced';
$lang['alternate_post_url'] = 'Alternate Transaction Submission URL';
$lang['alternate_test_url'] = 'Alternate Test Transaction Submission URL';


#B


#C
$lang['checkout_button_message'] = 'Checkout';
$lang['checkout_message'] = 'Checkout using Authorize.NET';

#D


#E
$lang['error_configuration'] = 'This module is not properly configured';
$lang['error_held_for_review'] = 'Payment has been held for review';
$lang['error_missing_data'] = 'Some information required for successfull transaction processing is not set';
$lang['error_payment_declined'] = 'Payment has been declined';
$lang['error_restoring_state'] = 'A problem occurred restoring gateway state information';
$lang['error_unknown'] = 'The payment gateway returned information we dont understand at this time';


#F
$lang['friendlyname'] = 'Authorize.net AIM';
$lang['form_template'] = 'Form Template';

#G


#H
$lang['help'] = <<<EOT
<h3>What does this do?</h3>
<p>This module provides the ability for your customers to pay for their purchases using their credit card directly on your site using the Authorize.Net secure gateway.</p>
<h3>Why should I use it?</h3>
<p>This gateway works without redirecting the user to a different website, and then redirecting them back.  It allows the ability to provide your customers with a single user experience.</p>
<h3>Special Requirements</h3>
<p>This module requires that your web application be configured to prompt the user for credit card information, The Orders module can be configured to do this.</p>
<p>Also this module will require a validated secure environment.   You will need to purchase a validated certificate from an approvded provider, install that certificate in your web host environment, and then configure CMS Made Simple to work properly in a secure environment.</p>
<h3>How do I use it?</h3>
<p>Quite simply, once all of the dependencies are installed, you simply install the module.  Then configure the module in the Authorize.NET AIM control panel in the CMS Made Simple admin console, using the transaction id, and the API Login that are provided to you by authorize.net. Then navigate to the preferences tab in the Orders module and select this module as your chosen payment gateway.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit the cms development forge at <a href="http://dev.cmsmadesimple.org">dev.cmsmadesimple.org</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, calguy1000 all can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author(s) directly.</li>  
</ul>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&lt;calguy1000@cmsmadesimple.org&gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>
EOT;


#I
$lang['info_alternate_urls'] = 'Some payment gateways have &quot;Authorize.NET&quot; emulators to allow using that payment gateway with alternate software.   Along with other details, they will provide alternate URLS for submitting the transactions.   You may specify those URLS here.   If these values are blank, then the system default URLS are used';
$lang['info_md5hash'] = 'The key used to encrypt certain information about the transaction, and to verify that transaction information came from a valid server.   You should configure the identical value in your authorize.net settings';
$lang['info_loginid'] = 'Please enter the Login ID provided to you by your authorize.net reseller';
$lang['info_testmode'] = 'With test mode enabled, no real transactions will be processed for logged in administrators.';
$lang['info_transactionkey'] = 'The transaction key value supplied to you by your authorize.net reseller';
$lang['info_usetesturl'] = 'Use the Authorize.net development environment instead of the real environment (requires having a developer account)';

#J


#K


#L


#M
$lang['moddescription'] = 'A payment gateway for the E-commerce system that uses the AIM protocol from Authorize.net';
$lang['msg_testmode'] = 'Test mode is enabled for logged in administrators';

#N


#O


#P
$lang['postinstall'] = 'Module successfully installed.  Please visit the module admin panel and ensure all preferences are set properly';
$lang['postuninstall'] = 'This module has been successfully uninstalled';
$lang['preferences'] = 'Preferences';
$lang['prompt_form_template'] = 'Edit the Form Template';
$lang['prompt_md5hash'] = 'MD5 Hash';
$lang['prompt_loginid'] = 'Authorize.Net API Login ID';
$lang['prompt_testmode'] = 'Enable Test Mode';
$lang['prompt_transactionkey'] = 'Transaction Key';
$lang['prompt_usetesturl'] = 'Use Developer account';

#Q


#R
$lang['really_uninstall'] = 'Are you sure you want to uninstall this module.  Continuing may have bad effects on an operational website';

#S
$lang['submit'] = 'Submit';


#T

#U


#V


#W


#X


#Y


#Z


?>
